@@ -7,8 +7,9 @@ import numpy
 import numpy as np
 import pandas
 from scipy.optimize import curve_fit
+from matplotlib.ticker import FixedLocator
 
-from .util import power_law
+from .util import power_law, inverse_power_law
 
 TWIN_COLOR = 'royalblue'
 
@@ -73,7 +74,13 @@ def show_selector(sy: pandas.DataFrame, figsize: Optional[Tuple[int, int]] = Non
 def show_depth(sy: pandas.DataFrame,
                height_of_line: Optional[float] = None,
                select: bool = False,
-               show_plot: bool = True) -> Optional[Union[Set[int], plt.Figure]]:
+               use_min_depth: bool = True,
+               show_plot: bool = True,
+               power_law_x_axis: bool = False,
+               show_legend: bool = False,
+               show_indexes: bool = False,
+               x_limits: Optional[Tuple[float, float]] = None,
+               y_limits: Optional[Tuple[float, float]] = None) -> Optional[Union[Set[int], plt.Figure]]:
     """Plot the depth in function of Sy.
 
     Examples
@@ -99,8 +106,21 @@ def show_depth(sy: pandas.DataFrame,
         If True, the data points can be selected on the plot.
         When the plot is closed, the index of the selected data points
         are returned.
+    use_min_depth
+        If True, the data points dans regression use the min_wtd as depth value.
+        If Fales, the mean depth (Depth column of Sy DataFrame) is used.
     show_plot
         If True, "plt.show()" is called, if False, the figure is return.
+    power_law_x_axis
+        If True, the Sy axis takes a power low graduation. If False, linear graduation.
+    show_legend
+        If True, show legend.
+    show_indexes
+        If true, a label with the index will point to its corresponding data point.
+    x_limits
+        Tuple of the limits for the x axis.
+    y_limits
+        Tuple of the limits for the y axis.
 
     Returns
     -------
@@ -125,13 +145,21 @@ def show_depth(sy: pandas.DataFrame,
         zorder=-1  # Visualy set the plot behind others
     )
 
+    # Use mean depth or mininal depth data points
+    depth_values_label = 'min_wtd' if use_min_depth else 'depth'
+
     # For the scatter plot
-    scatter_plot = ax.scatter(x=sy['sy'], y=sy['min_wtd'],
+    scatter_plot = ax.scatter(x=sy['sy'], y=sy[depth_values_label],
                               c=precepitation_sum, s=precepitation_sum,
                               vmin=min(precepitation_sum), vmax=max(precepitation_sum),
                               picker=select)
     fig.colorbar(scatter_plot, label='Precipitation sum [mm]')
 
+    # Annotation of the data points
+    if show_indexes:
+        for index, row in sy[['sy', depth_values_label]].iterrows():
+            ax.annotate(index, (row['sy'] + 0.01, row[depth_values_label] - 2))
+
     # Plotting the "asymptote" line
     sorted_sy = np.sort(sy['sy'])
 
@@ -139,17 +167,45 @@ def show_depth(sy: pandas.DataFrame,
         ax.plot(sorted_sy, [height_of_line for _ in sorted_sy], '--', color='gray', alpha=.5)
 
     # Curve fit
-    pars, cov = curve_fit(f=power_law, xdata=sy['sy'].values, ydata=sy['min_wtd'])
-    ax.plot(sorted_sy, power_law(sorted_sy, pars[0], pars[1]), color='gray', alpha=.5)
+    pars, cov = curve_fit(f=power_law, xdata=sy['sy'], ydata=sy[depth_values_label])
+    standard_deviation = numpy.sqrt(numpy.diag(cov))
+    a, b = pars[0], pars[1]
+    standard_deviation_a, standard_deviation_b = standard_deviation[0], standard_deviation[1]
+    ax.plot(
+        sorted_sy,
+        power_law(sorted_sy, a, b),
+        label=f'$Depth = a \cdot (Sy)^b$\n'
+              f'$\quad a = {a:.4f}\ cm, \sigma_a = {standard_deviation_a:.4f}\ cm$\n'
+              f'$\quad b = {b:.4f}\qquad, \sigma_b = {standard_deviation_b:.4f}$',
+        color='gray', alpha=.5
+    )
 
-    ax.set_ylim((-100, 0))
-    ax.set_xlim((0, 1))
+    if power_law_x_axis:
+        # Transforming Sy axis show an linear expression in plot
+        ax.set_xscale('function', functions=(lambda x: power_law(x, a, b), lambda x: inverse_power_law(x, a, b)))
+        ax.xaxis.set_major_locator(FixedLocator(numpy.arange(0, 2.1, 0.5)))
+
+        ax.set_ylim((-100, 0))
+        ax.set_xlim((sorted_sy.min()-0.001, sorted_sy.max()+0.001))
+
+    else:  # If note, plot with the default limits
+        ax.set_ylim((-100, 0))
+        ax.set_xlim((0, 1))
+
+    # Overwriting default limits if specified
+    if x_limits is not None:
+        ax.set_xlim(x_limits)
+    if y_limits is not None:
+        ax.set_ylim(y_limits)
 
     ax.xaxis.set_ticks_position('top')  # Putting x-axis on top
     ax.xaxis.set_label_position('top')
     ax.set_xlabel('Sy')
     ax.set_ylabel('Depth [cm]')
 
+    if show_legend:
+        plt.legend()
+
     plt.tight_layout()
 
     if select:
@@ -271,8 +327,8 @@ def show_water_level(
     Optional[matplotlib.figure.Figure]
         If "show_plot" is True, returns the plt.Figure. If False, returns None.
     """
-    beginning = sy['date_beginning'].iloc[event_index] - time_before
-    ending = sy['date_ending'].iloc[event_index] + time_after
+    beginning = sy['date_beginning'].loc[event_index] - time_before
+    ending = sy['date_ending'].loc[event_index] + time_after
 
     sub_time_series = time_series.loc[beginning:ending]
 
@@ -299,13 +355,13 @@ def show_water_level(
     ax_precipitation.tick_params(axis='y', colors=TWIN_COLOR)
 
     ax.scatter(
-        x=sy['idx_max'].iloc[[event_index]],
-        y=sy['max_wtd'].iloc[[event_index]],
+        x=sy['idx_max'].loc[[event_index]],
+        y=sy['max_wtd'].loc[[event_index]],
         s=100
     )
     ax.scatter(
-        x=sy['idx_min'].iloc[[event_index]],
-        y=sy['min_wtd'].iloc[[event_index]],
+        x=sy['idx_min'].loc[[event_index]],
+        y=sy['min_wtd'].loc[[event_index]],
         s=100
     )
     
